Foo
=========

1. Introduction
----------------

Foo is a demo project for creating and distributing python lib:

- it provides a directories to make a project.

- package and upload to pypi.org

Foo 是一个演示项目，用于展示创建和分发Python第三方库:

- 提供了一个Python第三方库项目目录文件样板

- 打包及上传pypi.org
